import React, { useCallback } from 'react';
import cn from 'classnames';
import { IconButton } from '@alfalab/core-components-icon-button/modern';
import { Link } from '@alfalab/core-components-link/modern';
import { Spinner } from '@alfalab/core-components-spinner/modern';
import { CrossMIcon } from '@alfalab/icons-glyph/CrossMIcon';
import { CheckmarkCircleMIcon } from '@alfalab/icons-glyph/CheckmarkCircleMIcon';
import { AlertCircleMIcon } from '@alfalab/icons-glyph/AlertCircleMIcon';
import { PointerDownMIcon } from '@alfalab/icons-glyph/PointerDownMIcon';
import { ClockMIcon } from '@alfalab/icons-glyph/ClockMIcon';
import '@alfalab/icons-glyph/DocumentDocMIcon';
import '@alfalab/icons-glyph/DocumentPdfMIcon';
import '@alfalab/icons-glyph/DocumentTxtMIcon';
import '@alfalab/icons-glyph/DocumentUnknownMIcon';
import '@alfalab/icons-glyph/DocumentImageMIcon';
import { fileIcon, humanFileSize } from './utils.js';

var styles = {"component":"file-upload-item__component_1osl5","infoSection":"file-upload-item__infoSection_1osl5","info":"file-upload-item__info_1osl5","icon":"file-upload-item__icon_1osl5","errorIcon":"file-upload-item__errorIcon_1osl5","successIcon":"file-upload-item__successIcon_1osl5","name":"file-upload-item__name_1osl5","meta":"file-upload-item__meta_1osl5","size":"file-upload-item__size_1osl5","delete":"file-upload-item__delete_1osl5","download":"file-upload-item__download_1osl5","errorWrapper":"file-upload-item__errorWrapper_1osl5","restore":"file-upload-item__restore_1osl5","spinnerWrapper":"file-upload-item__spinnerWrapper_1osl5","spinner":"file-upload-item__spinner_1osl5","uploadPercent":"file-upload-item__uploadPercent_1osl5"};
require('./index.css')

const FileUploadItem = ({ className, children, id = '0', name = '', size, icon: Icon = fileIcon(name), uploadDate, downloadLink, download, uploadStatus, uploadPercent = 0, error, showDelete, showRestore, onDelete, onDownload, onRestore, disableButtons, dataTestId, }) => {
    const handleDownload = useCallback((event) => {
        if (onDownload) {
            event.preventDefault();
            onDownload(id);
        }
    }, [id, onDownload]);
    const handleDelete = useCallback(() => {
        if (onDelete)
            onDelete(id);
    }, [id, onDelete]);
    const handleRestore = useCallback(() => {
        if (onRestore)
            onRestore(id);
    }, [id, onRestore]);
    const renderIcon = useCallback(() => {
        if (showRestore) {
            return React.createElement(ClockMIcon, { className: styles.restoreIcon });
        }
        switch (uploadStatus) {
            case 'ERROR':
                return React.createElement(AlertCircleMIcon, { className: styles.errorIcon });
            case 'SUCCESS':
                return React.createElement(CheckmarkCircleMIcon, { className: styles.successIcon });
            case 'LOADING':
            case 'UPLOADING':
                return (React.createElement("div", { className: styles.spinnerWrapper },
                    React.createElement(Spinner, { visible: true, className: styles.spinner })));
            default: {
                return React.createElement(Icon, { className: styles.icon });
            }
        }
    }, [showRestore, uploadStatus]);
    const renderInfoSection = useCallback(() => {
        const errorContent = uploadStatus === 'ERROR' && !error ? 'Не удалось загрузить файл' : error;
        return (React.createElement("div", { className: styles.infoSection },
            React.createElement("div", { className: styles.name }, name),
            error && (React.createElement("div", { className: styles.errorWrapper, role: 'alert' }, errorContent))));
    }, [name, uploadStatus, error]);
    const showMeta = !showRestore && (!uploadStatus || uploadStatus === 'SUCCESS');
    const showDownload = Boolean(downloadLink) && !showRestore;
    return (React.createElement("div", { className: cn(className, styles.component, uploadStatus && styles[uploadStatus.toLocaleLowerCase()]), "data-test-id": dataTestId },
        React.createElement("div", { className: styles.info },
            renderIcon(),
            renderInfoSection(),
            children,
            uploadStatus === 'UPLOADING' && (React.createElement("span", { className: styles.uploadPercent }, `${Math.round(uploadPercent)}%`)),
            showMeta && (React.createElement("div", { className: styles.meta },
                uploadDate && React.createElement("span", { key: uploadDate }, uploadDate),
                size && (React.createElement("span", { key: size, className: styles.size }, humanFileSize(size)))))),
        showRestore && (React.createElement(Link, { pseudo: true, className: styles.restore, onClick: handleRestore }, "\u0412\u043E\u0441\u0441\u0442\u0430\u043D\u043E\u0432\u0438\u0442\u044C")),
        showDownload && (React.createElement(IconButton, { size: 'xxs', icon: PointerDownMIcon, className: styles.download, "aria-label": '\u0441\u043A\u0430\u0447\u0430\u0442\u044C', href: downloadLink, onClick: handleDownload, disabled: disableButtons, download: download })),
        showDelete && !showRestore && (React.createElement(IconButton, { size: 'xxs', icon: CrossMIcon, onClick: handleDelete, disabled: disableButtons, className: styles.delete, "aria-label": '\u0443\u0434\u0430\u043B\u0438\u0442\u044C' }))));
};

export { FileUploadItem };
